@@ -13,7 +13,7 @@ use List::MoreUtils qw(none);
 use Scalar::Util qw(blessed);
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -233,10 +233,29 @@ L<UNIVERSAL::DOES> if doesn't exists in Perl.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Map::Tube::GraphViz>,
-L<Map::Tube::Text::Table>,
-L<Task::Map::Tube>.
+=over
+
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Map::Tube::GraphViz>
+
+GraphViz output for Map::Tube.
+
+=item L<Map::Tube::Plugin::Graph>
+
+Graph plugin for Map::Tube.
+
+=item L<Map::Tube::Text::Table>
+
+Table output for Map::Tube.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -256,6 +275,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
